summaryrefslogtreecommitdiffstats
path: root/keduca/keduca/kcheckeduca.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'keduca/keduca/kcheckeduca.cpp')
-rw-r--r--keduca/keduca/kcheckeduca.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/keduca/keduca/kcheckeduca.cpp b/keduca/keduca/kcheckeduca.cpp
index edeb42fd..5a9a60dc 100644
--- a/keduca/keduca/kcheckeduca.cpp
+++ b/keduca/keduca/kcheckeduca.cpp
@@ -38,7 +38,7 @@ void KCheckEduca::drawButtonLabel( TQPainter *p){
int extra_width, indicator_width;
extra_width = 8;
- indicator_width = tqstyle().pixelMetric(TQStyle::PM_IndicatorWidth, 0);
+ indicator_width = style().pixelMetric(TQStyle::PM_IndicatorWidth, 0);
y = 0;
x = indicator_width + extra_width; //###
@@ -68,7 +68,7 @@ void KCheckEduca::drawButtonLabel( TQPainter *p){
_doc->draw(p, cr.x()+xo, cr.y()+yo, cr, colorGroup(), 0);
if ( hasFocus() ) {
// TQRect br = tqstyle().itemRect( p, x, y, rw, rh+yo,
// AlignLeft|AlignVCenter|ShowPrefix,
// isEnabled(),
// pixmap(), text().visual() );
@@ -80,6 +80,6 @@ void KCheckEduca::drawButtonLabel( TQPainter *p){
br.setBottom( br.bottom()+2);
br = br.intersect( TQRect(0,0,rw, rh+yo ) );
- tqstyle().tqdrawPrimitive( TQStyle::PE_FocusRect, p, br, colorGroup());
+ style().tqdrawPrimitive( TQStyle::PE_FocusRect, p, br, colorGroup());
}
}
@@ -68,7 +68,7 @@ void KCheckEduca::drawButtonLabel( TQPainter *p){
_doc->draw(p, cr.x()+xo, cr.y()+yo, cr, colorGroup(), 0);
if ( hasFocus() ) {
-// TQRect br = tqstyle().itemRect( p, x, y, rw, rh+yo,
+// TQRect br = style().itemRect( p, x, y, rw, rh+yo,
// AlignLeft|AlignVCenter|ShowPrefix,
// isEnabled(),